function [poly] = insertCrackTip(FEM, qt, crack, cBlocks, cBlockId, xi, yi, cInd, bInd)
    %determine poly nodes
    nodes = cBlocks(cBlockId(bInd)).nodes;
    %insert intersect point
    nodes = [nodes;[xi,yi]];
    %unique
    nodes = uniquetol(nodes,'ByRows',true);
    %order
    cx1 = mean(nodes(:,1));cy1 = mean(nodes(:,2));
    a1 = atan2(nodes(:,2) - cy1, nodes(:,1) - cx1);
    [~, order] = sort(a1);
    nodes(:,1) = nodes(order,1);
    nodes(:,2) = nodes(order,2);
    %find nodes closest to intersection points
    distance = sqrt((xi-nodes(:,1)).^2+(yi-nodes(:,2)).^2);
    intId = find(distance<FEM.tol);
    %cirshift until intersect point in first place
    nodes = circshift(nodes,-(intId-1),1);
    %evaluate signed distance functions for first and last node
    points = [nodes(2,:);nodes(end,:)];
    sP = crack(cInd).points(1,:);eP = crack(cInd).points(2,:);
    d = sdLine(points,sP,eP) ;
    d = sign(d);
    %overwrite and append intersect point with FEM tolerances
    nodes(1,:) = [xi,yi]+d(1,1)*FEM.tol;
    nodes = [nodes;[xi,yi]+d(2,1)*FEM.tol];
    %find out with inpoly, which crack tip is currently considered
    xv = cBlocks(cBlockId(bInd)).nodes(:,1);
    yv = cBlocks(cBlockId(bInd)).nodes(:,2);
    xq = crack(cInd).points(:,1);
    yq = crack(cInd).points(:,2);
    in = inpolygon(xq,yq,xv',yv');
    %prepare return
     poly.nodes = nodes;
     poly.SC    = crack(cInd).points(in,:);
     poly.groupId = cBlocks(cBlockId(bInd)).groupID;
     poly.cracked = 1;
end
