function [poly] = splitBlockAtIntersect(FEM, qt, cBlocks, cBlockId, xi, yi, cInd, bInd)
    %partition block nodes according to sign of signed distance function
    nNodes = size(cBlocks(cBlockId(bInd)).nodes,1);
    sdEvalLine  = zeros(1,nNodes);
    for k = 1:1:nNodes
        sdEvalLine (1,k) = qt.crack{cInd}.line( cBlocks(cBlockId(bInd)).nodes(k,2)+1,cBlocks(cBlockId(bInd)).nodes(k,1)+1);
    end
    
    %create base points for polygon based on signed distance function evaluations at points
    poly1 = sdEvalLine <0;
    poly2 = sdEvalLine>=0;
    
    poly1 = [cBlocks(cBlockId(bInd)).nodes(poly1,:);[xi,yi]-FEM.tol];
    poly2 = [cBlocks(cBlockId(bInd)).nodes(poly2,:);[xi,yi]+FEM.tol];

    %order cw and unique
    poly1 = uniquetol(poly1,'ByRows',true);
    poly2 = uniquetol(poly2,'ByRows',true);

    cx1 = mean(poly1(:,1));cx2 = mean(poly2(:,1));
    cy1 = mean(poly1(:,2));cy2 = mean(poly2(:,2));
    a1 = atan2(poly1(:,2) - cy1, poly1(:,1) - cx1);
    a2 = atan2(poly2(:,2) - cy2, poly2(:,1) - cx2);
    [~, order1] = sort(a1);[~, order2] = sort(a2);
    poly1(:,1) = poly1(order1,1);
    poly1(:,2) = poly1(order1,2);
    poly2(:,1) = poly2(order2,1);
    poly2(:,2) = poly2(order2,2);
    
    %check if any of the polygons is empty
    if     isempty(poly1)
        poly.nodes   = [poly2(:,1), poly2(:,2)];
        poly.SC      = [mean(poly2(:,1)),mean( poly2(:,2))];
        poly.groupId = cBlocks(cBlockId(bInd)).groupID;
    elseif isempty(poly2)
        poly.nodes   = [poly1(:,1), poly1(:,2)];
        poly.SC      = [mean(poly1(:,1)),mean( poly1(:,2))];
        poly.groupId = cBlocks(cBlockId(bInd)).groupID;
    else
        poly(1).nodes   = [poly1(:,1), poly1(:,2)];
        poly(1).SC      = [mean(poly1(:,1)),mean( poly1(:,2))];
        poly(1).groupId = cBlocks(cBlockId(bInd)).groupID;
        
        poly(2).nodes   = [poly2(:,1), poly2(:,2)];
        poly(2).SC      = [mean(poly2(:,1)),mean( poly2(:,2))];
        poly(2).groupId = cBlocks(cBlockId(bInd)).groupID;
    end
end

    




    %store
    %cBlocks(cBlockId(j)).polygon(1).nodes = [poly1(:,1), poly1(:,2)];
    %cBlocks(cBlockId(j)).polygon(1).SC    = [mean(poly1(:,1)),mean( poly1(:,2))];
    %cBlocks(cBlockId(j)).polygon(1).groupId = cBlocks(cBlockId(j)).groupID;

    %cBlocks(cBlockId(j)).polygon(2).nodes = [poly2(:,1), poly2(:,2)];
    %cBlocks(cBlockId(j)).polygon(2).SC    = [mean(poly2(:,1)),mean( poly2(:,2))];
    %cBlocks(cBlockId(j)).polygon(2).groupId = cBlocks(cBlockId(j)).groupID;