function [poly] = splitPolyAtIntersect(FEM, qt, crack, cBlocks, cBlockId, xi, yi, cInd, bInd, pInd)
    %partition block nodes according to sign of signed distance function
    nodes = cBlocks(cBlockId(bInd)).polygon(pInd).nodes;
    sP = crack(cInd).points(1,:);eP = crack(cInd).points(2,:);
    sdEvalLine = sdLine(nodes,sP,eP);
    
    %create base points for polygon based on signed distance function evaluations at points
    poly1 = sdEvalLine <0;
    poly2 = sdEvalLine>=0;
    
    poly1 = [cBlocks(cBlockId(bInd)).polygon(pInd).nodes(poly1,:);[xi,yi]-FEM.tol];
    poly2 = [cBlocks(cBlockId(bInd)).polygon(pInd).nodes(poly2,:);[xi,yi]+FEM.tol];

    %order cw and unique
    poly1 = uniquetol(poly1,'ByRows',true);
    poly2 = uniquetol(poly2,'ByRows',true);

    cx1 = mean(poly1(:,1));cx2 = mean(poly2(:,1));
    cy1 = mean(poly1(:,2));cy2 = mean(poly2(:,2));
    a1 = atan2(poly1(:,2) - cy1, poly1(:,1) - cx1);
    a2 = atan2(poly2(:,2) - cy2, poly2(:,1) - cx2);
    [~, order1] = sort(a1);[~, order2] = sort(a2);
    poly1(:,1) = poly1(order1,1);
    poly1(:,2) = poly1(order1,2);
    poly2(:,1) = poly2(order2,1);
    poly2(:,2) = poly2(order2,2);
    
    %check if any of the polygons is empty
    if     size(poly1,1)<=2
        poly.nodes   = [poly2(:,1), poly2(:,2)];
        poly.SC      = [mean(poly2(:,1)),mean( poly2(:,2))];
        poly.groupId = cBlocks(cBlockId(bInd)).polygon(pInd).groupId;
    elseif size(poly2,1)<=2
        poly.nodes   = [poly1(:,1), poly1(:,2)];
        poly.SC      = [mean(poly1(:,1)),mean( poly1(:,2))];
        poly.groupId = cBlocks(cBlockId(bInd)).polygon(pInd).groupId;
    else
        poly(1).nodes   = [poly1(:,1), poly1(:,2)];
        poly(1).SC      = [mean(poly1(:,1)),mean( poly1(:,2))];
        poly(1).groupId = cBlocks(cBlockId(bInd)).polygon(pInd).groupId;
        
        poly(2).nodes   = [poly2(:,1), poly2(:,2)];
        poly(2).SC      = [mean(poly2(:,1)),mean( poly2(:,2))];
        poly(2).groupId = cBlocks(cBlockId(bInd)).polygon(pInd).groupId;
    end
end

    




    %store
    %cBlocks(cBlockId(j)).polygon(1).nodes = [poly1(:,1), poly1(:,2)];
    %cBlocks(cBlockId(j)).polygon(1).SC    = [mean(poly1(:,1)),mean( poly1(:,2))];
    %cBlocks(cBlockId(j)).polygon(1).groupId = cBlocks(cBlockId(j)).groupID;

    %cBlocks(cBlockId(j)).polygon(2).nodes = [poly2(:,1), poly2(:,2)];
    %cBlocks(cBlockId(j)).polygon(2).SC    = [mean(poly2(:,1)),mean( poly2(:,2))];
    %cBlocks(cBlockId(j)).polygon(2).groupId = cBlocks(cBlockId(j)).groupID;