function [qt, poly, domain, feature, crack, groups, FEM, BC, Load] = Input_File_1()
%%  Quadtree related
    qt.decompMin            =    4;
    qt.decompMax            =  512;
    qt.size                 = 1024;
    qt.nKids                =    4;
    qt.maxSeeds             =    1;
    qt.decompDoubleBalanced =    0;
    
%%  Polygon clipping related
    poly.rotAngle = 45;
    
%%  Plotting
    qt.plotScaleFactor = 100;
    qt.plotUnbalanced  = 0;
    qt.plotBalanced    = 0;
    qt.plotDomain      = 0;
    qt.plotTransition  = 0;
    qt.plotFinalMesh   = 0;
    
%%  Domains
    domainMultiplier  = 10;

    domain(1).type  = {'polyline','plus',1};
    domain(1).edges = [50,130;50,70;400,35;400,165];
    domain(1).seeds = domainMultiplier.*[2,20,2,20];
    
    domain(2).type  = {'ellipse','plus',1};
    domain(2).edges = [50,100;40,40];
    domain(2).seeds = domainMultiplier.*25;
    
    domain(3).type  = {'ellipse','plus',1};
    domain(3).edges = [400,100;90,90];
    domain(3).seeds = domainMultiplier.*25;
    
    domain(4).type  = {'ellipse','minus',1};
    domain(4).edges = [50,100;20,20];
    domain(4).seeds = domainMultiplier.*25;
    
    domain(5).type  = {'ellipse','minus',1};
    domain(5).edges = [400,100;40,40];
    domain(5).seeds = domainMultiplier.*25;
    
%%  Features
    featureMultiplier = 10;

    feature(1).type  = {'ellipse','plus',2};
    feature(1).edges = [150,100;20,20];
    feature(1).seeds = featureMultiplier.*25;
    
    feature(2).type  = {'ellipse','plus',3};
    feature(2).edges = [275,100;30,30];
    feature(2).seeds = featureMultiplier.*25;
    
    feature(3).type  = {'ellipse','plus',2};
    feature(3).edges = [175,100;25,25];
    feature(3).seeds = featureMultiplier.*25;
    
%%  Cracks
    crack(1).points = [150,50;200,125];
    
%%  Material properties of each group
    groups(1).E = 100;
    groups(1).v = 0.3;
    
    groups(2).E = 10;
    groups(2).v = 0.25;
    
    groups(3).E = 10;
    groups(3).v = 0.2;
    
%%  Global FEM parameters
    FEM.nodesPerElement   = 2;  %currently the code is locked in to 2-noded elements
    FEM.quadratureType    = 1;  %Gauss = 1, Lobatto = 2
    FEM.constitutiveLaw   = 2;

    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5;
    
%%  Loading
    Load = [];

%%  Boundary conditions
    BC(1).set   = {'domain',4};  %target nodes of domain 4
    BC(1).coord = [1,1];         %enforce on both (x,y)-DOF
    BC(1).value = [0,0];         %restrained against displacement
    
    BC(2).set   = {'domain',5};  %target nodes of domain 5
    BC(2).coord = [1,1];         %enforce on y-DOF
    BC(2).value = [0,-1];         %displacement of 1 IN UNSCALED UNITS!restrained against displacement
    

end





















