function [qt, poly, domain, feature, crack, groups, FEM, BC, Load] = Input_File_3b()
%%  Quadtree related
    qt.decompMin            =    4;
    qt.decompMax            =   64;%64
    qt.size                 = 1024;
    qt.nKids                =    4;
    qt.maxSeeds             =    1;
    qt.decompDoubleBalanced =    0;
    
%%  Polygon clipping related
    poly.rotAngle = 45;
    
%%  Plotting
    qt.plotUnbalanced  = 0;
    qt.plotBalanced    = 0;
    qt.plotDomain      = 0;
    qt.plotTransition  = 0;
    qt.plotFinalMesh   = 0;
    qt.plotScaleFactor = 10^-4;
    
%%  Domains
    domainMultiplier  = 1;
    tM = 150;
    
    w = 25.4*12;
    h = 25.4*24.6;
    
    domain(1).type  = {'polyline','plus',1};
    domain(1).edges = [0,0;w,0;w,h;0,h];
    domain(1).seeds = domainMultiplier.*[tM,1,tM,1];
    
%%  Features
    featureMultiplier = 25;
    
    w1 = 0.8; w2 = 12-0.8;
    
    %E = 4.4; F = 3.15; G = 3.2;
    E = 4.36451612903226; F = 3.17419354838710; G = 3.17419354838710;
    
    h1 = E; h2 = E+F; h3 = E+2*F; h4 = E+2*F+G; h5 = E+2*F+G+F; h6 = E+2*F+G+2*F;
    
    r = 4;
    
    w_f = 25.4*[w2,w2,w2,w2,w2,w2,w1,w1,w1,w1,w1,w1];
    h_f = 25.4*[h1,h2,h3,h4,h5,h6,h1,h2,h3,h4,h5,h6]; 
    
    for i = 1:1:length(w_f)
        feature(i).type  = {'ellipse','plus',1};
        feature(i).edges = [w_f(i),h_f(i);r,r];
        feature(i).seeds = featureMultiplier;
    end
    
%%  Cracks
    crack(1).points = 25.4*[(12/2+0.4    ),(14.6806451612903e+000    );...
                            (12/2+0.4+0.6),(14.6806451612903e+000+0.6)];
    %crack(1).points = 25.4*[(12/2+0.4    ),(24.6/2+2.36    );...
    %                        (12/2+0.4+0.6),(24.6/2+2.36+0.6)];
    
    %crack = [];
    
%%  Material properties of each group
    groups(1).E = 2.04643291e+5;%2.04643291e+5;
    groups(1).v = 0.2826;
    
    %E_Eleni = 2.04643291e+11
    %v_Eleni = 0.2826
    %F_Eleni = ???
    
%%  Global FEM parameters
    FEM.nodesPerElement   = 2;  %currently the code is locked in to 2-noded elements
    FEM.quadratureType    = 1;  %Gauss = 1, Lobatto = 2
    FEM.constitutiveLaw   = 2;

    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5;
    
%%  Loading
    qt.loadMagnitude = 2*1.1*10^8;%1.135*10^8;
    
    Load(1).set   = {'bottom',25.4*[4,8]};
    Load(1).value = [0,-qt.loadMagnitude];
    Load(1).distr = 'uniform';

%%  Boundary conditions

    BC(1).set   = {'set','top',25.4*[4,8]};       
    BC(1).coord = [1,1];               
    BC(1).value = [0,0];
    
%%  Fixed points
    qt.fixedPoints = 25.4*[w1,h1;w1,h2;w1,h3;w1,h4;w1,h5;w1,h6;...
                           w2,h1;w2,h2;w2,h3;w2,h4;w2,h5;w2,h6;...
                           4,0;8,0;...
                           4,24.6;8,24.6];
    
end





















