function [patchElements, eta, dist, flag] = findPatchElements(FEM,SD)
    flag = 0;
    %line
        %starting point
            %is the crack tip
        %slope
            slope = (SD.SC(2)-SD.nodes(1,2))/(SD.SC(1)-SD.nodes(1,1));
        %ending point
            extensionFactor = 1/FEM.tol;
            direction = sign(SD.SC(1)-SD.nodes(1,1));
            endPoint = [SD.SC(1)+extensionFactor*FEM.width*direction,SD.SC(2)+slope*extensionFactor*direction];
        %create line
            xLine=[SD.SC(1);endPoint(1)];
            yLine=[SD.SC(2);endPoint(2)];
    %box is boundary polygon
        xPGon = SD.bPolygon(:,1);
        yPGon = SD.bPolygon(:,2);
        
    %intersection
    [xI, yI] = polyxpoly(xLine, yLine, xPGon, yPGon);
    dist = sqrt((xI-SD.SC(1))^2+(yI-SD.SC(2))^2);
    
    %find if intersection is close to the boundary polygon edges
    distance = sqrt((xI-SD.bPolygon(:,1)).^2+(yI-SD.bPolygon(:,2)).^2);
    if min(distance) < FEM.tol; flag = 1; end
    
    %find nearest node
    distance = sqrt((xI-SD.nodes(:,1)).^2+(yI-SD.nodes(:,2)).^2);
    [~,ind] = min(distance);
    
    %find pertaining element
    [element,node]=find(abs(SD.localElements-ind)<FEM.tol);
    [element,sortInd] = sort(element,'ascend');
    node = node(sortInd);
    
    %determine eta as distance from
    sNode = SD.localElements(element(1),1);
    distance = sqrt((xI-SD.nodes(sNode,1)).^2+(yI-SD.nodes(sNode,2)).^2);
    [ xCoord , yCoord ] = elementNodeCoordinates( SD.nodes , SD.localElements , element(1) , FEM.nodesPerElement, SD.SC);
    elementLength = sqrt((xCoord(1,:)-xCoord(end,:))^2 + (yCoord(1,:)-yCoord(end,:))^2);
    eta = distance/elementLength*2-1;
    
    %find neighbouring element
    if length(element) == 2
        patchElements = element';
    elseif length(element) == 1
        switch element
            case 1; patchElements = [element,2];
            case SD.numberOfElements; patchElements = [SD.numberOfElements-1,element]; eta = eta + 2;
            otherwise
                if node <= FEM.nodesPerElement / 2
                    patchElements = [element-1,element]; eta = eta + 2;
                else
                    patchElements = [element,element+1];
                end
        end
    end
        %check flag
        for i = 1:1:length(SD.sumEPS)
            if (patchElements(1) <= SD.sumEPS(i) && patchElements(2) >= SD.sumEPS(i)) || (patchElements(2) <= SD.sumEPS(i) && patchElements(1) >= SD.sumEPS(i))
                flag = 1;
            end
        end 
end