function[nodes, elements, elementsPerSide] = generateMesh_LobattoSpacing(FEM,SD)

%%  Parameters
    %Generate elements per side based on length and approximate element size
    elementsPerSide = [];
    
    numberOfSides = size(SD.bPolygon,1) - 1;
    
    nodes = [];
    
    [ samplingPoints , ~ ] = integrationParameters1D ( FEM.nodesPerElement , FEM.quadratureType);
    samplingPoints = (samplingPoints +1)./2;
    
%%  Generate Nodes
    
    for i= 1:1:numberOfSides
        startingX = SD.bPolygon(i  ,1);
        endingX   = SD.bPolygon(i+1,1);
        startingY = SD.bPolygon(i  ,2);
        endingY   = SD.bPolygon(i+1,2);
        
        sideLength = sqrt((endingX-startingX)^2+(endingY-startingY)^2);
        
        sideElements = round(sideLength/SD.approxElementSize);
        
        elementsPerSide = [elementsPerSide,sideElements];
        
        elementLength = sideLength ./elementsPerSide(i);
        
        for j = 1:1:elementsPerSide(i)
            sX = startingX + (endingX-startingX) * (j-1)*elementLength/sideLength;
            eX = startingX + (endingX-startingX) * (j  )*elementLength/sideLength;
            sY = startingY + (endingY-startingY) * (j-1)*elementLength/sideLength;
            eY = startingY + (endingY-startingY) * (j  )*elementLength/sideLength;
            dX = eX-sX;
            dY = eY-sY;
            
            nodesX = sX + dX * samplingPoints(1:end-1);
            nodesY = sY + dY * samplingPoints(1:end-1);
            
            nodes = [nodes;[nodesX',nodesY']];
        end
    end
    
    %perturb last node, which is double crack node
    if SD.cracked == 1
        nodes = [nodes; SD.bPolygon(end,:)];
    end
    
    numberOfElements = sum(elementsPerSide);
    
%%  Generate Elements
    elements = zeros(numberOfElements, FEM.nodesPerElement);
    
    for i = 1:1:numberOfElements
        start = (i-1)*(FEM.nodesPerElement - 1) + 1;
        elements(i,:) = start: start + FEM.nodesPerElement - 1;
    end
    if SD.cracked == 0
        elements(end,end) = 1;
    end

end