function [F] = getForceVectorTensionSubdomain(FEM, SD)
%%  Construct force vector  
    %parameters for numerical integration of forces
    F = zeros(SD.nDOF,1);
    DOFPerElement = FEM.DOFPerNode * FEM.nodesPerElement;
    
    %%  Numerical integration values
    [ samplingPoints , weights ] = integrationParameters1D ( FEM.nodesPerElement , FEM.quadratureType);
    numberOfSamplingPoints = length(samplingPoints);
    
    %for the elements of the lower side
    for i = 1:1:length(SD.loadedElements)
        %initialize loading vector
        F_loc = zeros(DOFPerElement,1);
        %determine element properties
        [ xCoord , yCoord ] = elementNodeCoordinates( SD.nodes , SD.localElements , SD.loadedElements(1,i) , FEM.nodesPerElement, SD.SC);
        elementLength = sqrt((xCoord(1,:)-xCoord(end,:))^2 + (yCoord(1,:)-yCoord(end,:))^2);
        detJ = elementLength/2;
        
        %proceed with numerical integration
        for j = 1:1:numberOfSamplingPoints
            
            samplingPoint = samplingPoints(j);
            [shapeFunction , ~] = shapeFunction1D (FEM.nodesPerElement , samplingPoint, FEM.quadratureType);

            numberOfShapeFunctions = length(shapeFunction);

            %recall specific integration weights
            weight = weights(j);
            
            %specify shape function for each DOF
            %initialize shape function and it's derivatives in 2D
                shapeFunction2D           = zeros( FEM.DOFPerNode , DOFPerElement );
            %construct shape functions and associated derivaties in 2D
                positionCounter = 1;
                for k = 1:1:numberOfShapeFunctions
                    %abbreviation for simple notation
                    positionRow = 1:FEM.DOFPerNode;
                    positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                    shapeFunction2D(positionRow,positionCol)           = shapeFunction(k) * eye(2);
                    positionCounter = positionCounter + FEM.DOFPerNode;
                end
            F_loc = F_loc + shapeFunction2D' * SD.loading .* detJ .* weight;                
        end
        
        %add F_loc to subdomain loading vector
            %save coefficient matrix contribution in correct position
                %determine saving position
                ind  = nodesToDOF(SD.localElements(SD.loadedElements(1,i),:)',FEM.DOFPerNode);
                
        F(ind,1) = F(ind,1) + F_loc;
    end
    