function [FEM,SD] = inputFile_2()
%%  double edge crack modelled with two domains

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %working switches
    FEM.verbose = 2;
    FEM.clear   = 1;
    FEM.timing  = 1;
    
    %plotting switches
    FEM.plotMesh          = 0;
    FEM.plotDisplacements = 1;
    
    %working switches
    switch FEM.clear
        case 0  %do nothing
        case 1; clc;
        case 2; clc; close all;
        case 3; clear all; close all; clc;
    end
    if FEM.timing; FEM.tAnalysisStart = tic; end
    if FEM.verbose; fprintf(1,'Starting SBFEM analysis\n'); fprintf('******************************************\n');end
    if FEM.verbose; fprintf(1,' 1. Processing global input parameters...'); end

    %Analysis options
    FEM.elementSizeFactor = 5;
    FEM.nodesPerElement   = 5;
    FEM.quadratureType    = 2;
    FEM.constitutiveLaw   = 2;
    
    %Geometry and crack information
    FEM.width       = 1;
    FEM.height      = 1;
    FEM.crackLength = FEM.width/2; 
    FEM.crackAngle  = 0;%pi()/4;
    FEM.crackMiddle = [FEM.width/2,FEM.height/2];
    
    %Load information
    FEM.load = 0.1;
    
    %Various other parameters
    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5; %changes manifest also in mesher!
    FEM.plotScalingFactor = 250;
    
    if FEM.verbose; fprintf('done!\n'); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Subdomains
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if FEM.verbose; fprintf(1,' 2. Processing subdomains...'); end
    %alias
    w = FEM.width;
    h = FEM.height;

    %subdomain 1
    SD(1).SC = FEM.crackMiddle - FEM.crackLength/2 .* [cos(FEM.crackAngle),sin(FEM.crackAngle)];
    SD(1).E = 200;
    SD(1).v = 0.3;
    SD(1).L = 2*FEM.crackLength;
    
    SD(1).bPolygon = [[0,h/2];[0,0];[w/2,0];[w/2,h];[0,h];[0,h/2]];
    SD(1).bPolygon(1,2) = SD(1).bPolygon(1,2) + FEM.tol^3;
    
    SD(1).approxElementSize = 0.5*FEM.width / FEM.elementSizeFactor;
    SD(1).cracked = 1;
    
    %subdomain 2
    SD(2).SC = FEM.crackMiddle + FEM.crackLength/2 .* [cos(FEM.crackAngle),sin(FEM.crackAngle)];
    SD(2).E = 200;
    SD(2).v = 0.3;
    SD(2).L = 2*FEM.crackLength;
    
    SD(2).bPolygon = [[w,h/2];[w,h];[w/2,h];[w/2,0];[w,0];[w,h/2]];
    SD(2).bPolygon(end,2) = SD(2).bPolygon(end,2) + FEM.tol^3;
        
    SD(2).approxElementSize = 0.5*FEM.width / FEM.elementSizeFactor;
    SD(2).cracked = 1;
    
    if FEM.verbose; fprintf('done!\n'); end
    if FEM.verbose == 2; fprintf('\tnumber of subdomains = %d\n',length(SD)); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Loading
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SD(1).FSide{1} = {'t',[0,1, FEM.load]}; % load top side of SD with load in y-direction
    SD(1).FSide{2} = {'b',[0,1,-FEM.load]}; % load top side of SD with load in y-direction
    
    SD(2).FSide{1} = {'t',[0,1, FEM.load]}; % load top side of SD with load in y-direction
    SD(2).FSide{2} = {'b',[0,1,-FEM.load]}; % load top side of SD with load in y-direction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Boundary Conditions (as local nodes)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    FEM.BCSide = [];
    
    FEM.BCPoint{1} = {'bm',[1,1]}; %bottom-middle point is restrained in x&y-direction
    FEM.BCPoint{2} = {'tm',[1,0]}; %top-middle point is restrained in x&y-direction

end


















