function [FEM,SD] = inputFile_5()
%%  generates stiffness matrices for balanced quadtree sanity checks
    %add breakpoint right after K is calculated
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Input
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %working switches
    FEM.clear   = 3;    %1 = clc; 2 = clc, close all; 3 = clear all, close all, clc
    switch FEM.clear
        case 0  %do nothing
        case 1; clc;
        case 2; clc; close all;
        case 3; clear all; close all; clc;
    end
    
    FEM.verbose = 0;    %0 = no output; 1 = progress ouput; 2 = SIFs and nDOF ouput 
    FEM.timing  = 1;    %0 = no timings; 1 = all timings
    
    %plotting switches
    FEM.plotMesh          = 1;  %0 = no plot; 1 = plot
    FEM.plotDisplacements = 0;  %0 = no plot; 1 = plot
    
    %working switches
    if FEM.timing; FEM.tAnalysisStart = tic; end
    if FEM.verbose; fprintf(1,'Starting SBFEM analysis\n'); fprintf('******************************************\n');end
    if FEM.verbose; fprintf(1,' 1. Processing global input parameters...'); end

    %Analysis options
    FEM.elementSizeFactor = 1;                                          %modify
    FEM.nodesPerElement   = 2;                                          %modify
    FEM.quadratureType    = 2;      %1 = Gauss; 2 = Lobbatto
    FEM.constitutiveLaw   = 2;      %1 = plain strain; 2 = plain stress
    
    %Geometry and crack information
    FEM.width       = 1;
    FEM.height      = 1;                                        
    
    %Load information
    FEM.load = 0.1;
    
    %Various other parameters
    FEM.DOFPerNode = 2;
    FEM.DOFPerElement   = FEM.DOFPerNode * FEM.nodesPerElement;
    
    FEM.tol = 10^-5; %changes manifest also in perturbing nodes!
    FEM.plotScalingFactor = 250;
    
    if FEM.verbose; fprintf('done!\n'); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Subdomains
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if FEM.verbose; fprintf(1,' 2. Processing subdomains...'); end
    %alias
    w = FEM.width;
    h = FEM.height;

    %subdomain 1
    SD(1).SC = [w/2,h/2];           %scaling center || crack tip
    SD(1).E =   1;                  %E-modulus
    SD(1).v = 0.3;                  %Poisson ratio
    
    %SD(1).bPolygon = [[0,0];[w,0];[w,h];[0,h];[0,0]]; %4&8-noded blocks
    %5A
    %SD(1).bPolygon = [[0,0];[w/2,0];[w,0];[w,h];[0,h];[0,0]]; %5-noded blocks
    %5B
    %SD(1).bPolygon = [[0,0];[w,0];[w,h/2];[w,h];[0,h];[0,0]]; %5-noded blocks
    %5C
    %SD(1).bPolygon = [[0,0];[w,0];[w,h];[w/2,h];[0,h];[0,0]]; %5-noded blocks
    %5D
    SD(1).bPolygon = [[0,0];[w,0];[w,h];[0,h];[0,h/2];[0,0]]; %5-noded blocks
    
    SD(1).approxElementSize = FEM.width / FEM.elementSizeFactor;
    SD(1).cracked = 0;  %0 = no crack; 1 = crack

    if FEM.verbose; fprintf('done!\n'); end
    if FEM.verbose == 2; fprintf('\tnumber of subdomains = %d\n',length(SD)); end
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Loading
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    SD(1).FSide{1} = {'t',[0,1, FEM.load]}; % +load top    side of SD with load in y-direction

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Boundary Conditions (as local nodes)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    FEM.BCSide  = [];
    FEM.BCPoint = [];
end


















