function [samplingPoints , weights] = integrationParameters1D (nodesPerElement, quadratureType)
    switch quadratureType
        case(1) %Gauss-Legendre
            %fprintf('Applying Gauss-Legendre quadrature \n');
            switch nodesPerElement
                case(1) %lower grade of integration for loading vector
                    samplingPoints = 0;
                    weights = 2;
                case(2) %2-node element
                    samplingPoints = [ -sqrt( 1 / 3 ) , sqrt( 1 / 3 ) ];
                    weights = [ 1 , 1 ];
                case(3) %3-node element
                    samplingPoints = [ - sqrt( 3 / 5 ), 0 , sqrt( 3 / 5 )];
                    weights = [ 5 / 9 , 8 / 9 , 5 / 9 ];
                case(4) %4-node element
                    samplingPoints = [-sqrt((3/7)+(2/7)*sqrt(6/5)), -sqrt((3/7)-(2/7)*sqrt(6/5)), sqrt((3/7)-(2/7)*sqrt(6/5)), sqrt((3/7)+(2/7)*sqrt(6/5))];
                    weights = [(18-sqrt(30))/36, (18+sqrt(30))/36, (18+sqrt(30))/36, (18-sqrt(30))/36];
                case(5) %5-node element
                    samplingPoints = [-(1/3)*sqrt(5+2*sqrt(10/7)), -(1/3)*sqrt(5-2*sqrt(10/7)), 0, (1/3)*sqrt(5-2*sqrt(10/7)), (1/3)*sqrt(5+2*sqrt(10/7))];
                    weights = [(322-13*sqrt(70))/(900), (322+13*sqrt(70))/(900), 128/225, (322+13*sqrt(70))/(900), (322-13*sqrt(70))/(900)];
                case(6) %6-node element
                    samplingPoints = [-0.932469514203152, -0.661209386466265, -0.238619186083197,...
                                       0.238619186083197,  0.661209386466265,  0.932469514203152];

                    weights = [0.171324492379170, 0.360761573048139, 0.467913934572691, ...
                               0.467913934572691, 0.360761573048139, 0.171324492379170];
                otherwise
                    fprintf('\nFAILURE: Please specify a valid number of nodes per line element! \n');
            end
        case(2) %Gauss-Lobatto
            %fprintf('Applying Gauss-Lobatto quadrature \n');
            switch nodesPerElement
                case(2) %2-node element
                    samplingPoints = [-1, 1];
                    weights = [1, 1];
                case(3) %3-node element
                    samplingPoints = [-1,  0, 1];
                    weights = [0.333333333333333333d0, 1.33333333333333333d0, 0.333333333333333333d0];
                case(4) %4-node element
                    samplingPoints = [-1, -0.447213595499957939d0, 0.447213595499957939d0, 1];
                    weights = [0.166666666666666667d0, 0.833333333333333333d0, 0.833333333333333333d0, 0.166666666666666667d0];
                case(5) %5-node element
                    samplingPoints = [-1, -0.654653670707977144d0, 0, 0.654653670707977144d0, 1];
                    weights = [0.1d0, 0.544444444444444444d0, 0.711111111111111111d0, 0.544444444444444444d0, 0.1d0];
                case(6) %6-node element
                    samplingPoints = [-1, -0.765055323929464693d0, -0.285231516480645096d0,0.285231516480645096d0,0.765055323929464693d0,1];
                    weights = [0.0666666666666666667d0, 0.37847495629784698d0, 0.554858377035486353d0,0.554858377035486353d0,0.37847495629784698d0,0.0666666666666666667d0];
                otherwise
                    fprintf('\nFAILURE: Please specify a valid number of nodes per line element! \n');
            end
        otherwise
            disp('invalid quadrature type');
    end
                