%%  Testing and plotting standard westergaard solution for K_1 = 1

%%  Parameters (same as in SBFEM input file!)
    E  = 200;
    v  = 0.3;
    k1 = 1;
    mu = E/(2*(1+v));
    ka = (3-v)/(1+v);
    
    plotting = 0;
    
%%  Displacements according to westergaard solution
    %generate cartesian points on the boundary via SBFEM mesher
    x = SD.nodes(:,1)-SD.SC(1,1);
    y = SD.nodes(:,2)-SD.SC(1,2);
    
    %transform to polar
    [theta,r] = cart2pol(x,y);
    
    %flip sign of theta of first node since matlab does not find it to be negative
    theta(1,1) = sign(theta(1,1))*-pi;

    %displacements
    ux = k1/(2*mu).*sqrt(r./(2*pi)).*cos(theta./2).*(ka-1+2.*sin(theta./2).^2);
    uy = k1/(2*mu).*sqrt(r./(2*pi)).*sin(theta./2).*(ka+1-2.*cos(theta./2).^2);
    
    %prescribed displacements westergaard
    pDispWest = [ux,uy];
    pDispWest = reshape(pDispWest',[],1);

    %process for plotting
    scale = 10;

    dispx = x+scale*ux;
    dispy = y+scale*uy;

    if plotting
    hold on
    scatter(x,y);
    scatter(dispx,dispy,'b');
    axis equal
    hold off
    end

%%  Displacements according to Westergaard solution at edge points and linear interpolation
    %find index of nodes that represent the boundary polygon
    [~,iN2P]=ismember(SD.bPolygon,SD.nodes,'rows');
    [~,iP2N]=ismember(SD.nodes,SD.bPolygon,'rows');
    
    %Obtain displacements first fom edges and linearly interpolate for side nodes
    x = SD.bPolygon(:,1)-SD.SC(1,1);
    y = SD.bPolygon(:,2)-SD.SC(1,2);
    xN = SD.nodes(:,1)-SD.SC(1,1);
    yN = SD.nodes(:,2)-SD.SC(1,2);
    %transform to polar
    [theta,r] = cart2pol(x,y);
    %flip sign of theta of first node since matlab does not find it to be negative
    theta(1,1) = sign(theta(1,1))*-pi;
    %displacements
    ux = k1/(2*mu).*sqrt(r./(2*pi)).*cos(theta./2).*(ka-1+2.*sin(theta./2).^2);
    uy = k1/(2*mu).*sqrt(r./(2*pi)).*sin(theta./2).*(ka+1-2.*cos(theta./2).^2);

    pDispInt = zeros(SD.numberOfNodes,2);
    %assign edge nodes first according to westergaard solution
    for i = 1:1:length(iN2P)
        pDispInt(iN2P(i,1),:) = [ux(i),uy(i)];
    end
    %interpolate for side nodes
    for i = 1:1:length(SD.elementsPerSide)
        sP = iN2P(i  );
        eP = iN2P(i+1);
        iS = sP+1;
        iE = eP-1;
        iP = iS:1:iE;
        for j = 1:1:length(iP)
            distSE = sqrt((SD.nodes(eP   ,1)-SD.nodes(sP,1))^2+(SD.nodes(eP   ,2)-SD.nodes(sP,2))^2);
            distSI = sqrt((SD.nodes(iP(j),1)-SD.nodes(sP,1))^2+(SD.nodes(iP(j),2)-SD.nodes(sP,2))^2);
            ratio = distSI/distSE;
            dx = pDispInt(eP,1)-pDispInt(sP,1);
            dy = pDispInt(eP,2)-pDispInt(sP,2);
            pDispInt(iP(j),1) = pDispInt(sP,1)+dx*ratio;
            pDispInt(iP(j),2) = pDispInt(sP,2)+dy*ratio;
        end
    end
    
    if plotting
    %plotting
    dispPX = xN+scale*pDispInt(:,1);
    dispPY = yN+scale*pDispInt(:,2);
    hold on
    scatter(dispPX,dispPY,'r');
    axis equal
    hold off
    end
    
    %rearrange pDispInt to reflect (x,y)-DOF
    pDispInt = reshape(pDispInt',[],1);
    
%%  Determine lambda and SIFs of quadtree based block
    %{
        change inputFile_6 to values below and run:
        FEM.elementSizeFactor = 1;                                          %modify
        FEM.nodesPerElement   = 2;                                          %modify
        comment out line 107 from SBFEM_2D_static and replace with
        
    %}

    %SD(i).C = SD(i).Q \ pDispInt;
    
    