function [phi] = calcSIFStressModes(b,FEM)
    %define sizes for matrices
    [ samplingPoints , ~ ] = integrationParameters1D ( FEM.nodesPerElement , FEM.quadratureType);
    numberOfSamplingPoints = length(samplingPoints);
    stressModes = zeros(b.numberOfElements*numberOfSamplingPoints,3,2); %number of integration points, 3 components, 2 singular modes
    thetas = zeros(b.numberOfElements*numberOfSamplingPoints,1);
    radius = zeros(b.numberOfElements*numberOfSamplingPoints,1);
    
    counter = 1;
    
    for i = 1:1:b.numberOfElements 
        %recall (x,y)-coordinates of each elements nodes
        [ xCoord , yCoord ] = elementNodeCoordinates( b.nodes , b.localElements , i , FEM.nodesPerElement, b.SC);
        %recall material properties for each element to form corresponding matrix
        [ D ] = constitutiveMatrix2D( b.E , b.v , FEM.constitutiveLaw );
        
        for j = 1:1:numberOfSamplingPoints
            samplingPoint = samplingPoints(j);
            [shapeFunction , shapeFunctionDerivative] = shapeFunction1D (FEM.nodesPerElement , samplingPoint, FEM.quadratureType);
            numberOfShapeFunctions = length(shapeFunction);
            %recall interpolation of cartesian coordinates (x,y) and their derivates
            x   = shapeFunction * xCoord;           y   = shapeFunction * yCoord;
            x_n = shapeFunctionDerivative * xCoord; y_n = shapeFunctionDerivative * yCoord;
            %calculate specific jacobian and it's determinant
            detJ = x * y_n - y * x_n;
            
            %specify shape function for each DOF
                %initialize shape function and it's derivatives in 2D
                    shapeFunction2D           = zeros( FEM.DOFPerNode , FEM.DOFPerElement );
                    shapeFunctionDerivative2D = zeros( FEM.DOFPerNode , FEM.DOFPerElement );

                %construct shape functions and associated derivaties in 2D
                    positionCounter = 1;
                    for k = 1:1:numberOfShapeFunctions
                        %abbreviation for simple notation
                        positionRow = 1:FEM.DOFPerNode;
                        positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                        shapeFunction2D(positionRow,positionCol)           = shapeFunction(k)           * eye(2);
                        shapeFunctionDerivative2D(positionRow,positionCol) = shapeFunctionDerivative(k) * eye(2);
                        positionCounter = positionCounter + FEM.DOFPerNode;
                    end

            %calculate strain desplacement matrices B1 B2
            B1 =   1/detJ * [y_n ,   0 ;...
                               0 , -x_n;...
                            -x_n ,  y_n] * shapeFunction2D;
            B2 =   1/detJ * [ -y ,   0 ;...
                               0 ,   x ;...
                               x ,  -y ] * shapeFunctionDerivative2D;
                           
            radius(counter) = sqrt(x^2+y^2);
            thetas(counter) = atan2d(y,x);
            
            eDOF = nodesToDOF(b.localElements(i,:)',FEM.DOFPerNode);
            stressMode = D*(-B1*b.sQ(eDOF,:)*b.sL + B2*b.sQ(eDOF,:)) * expm((-b.sL-eye(2))*log(b.charL/radius(counter)));
            %rotate
            c = cosd(thetas(counter)); s = sind(thetas(counter)); rotation = [c^2,s^2,2*c*s;s^2,c^2,-2*s*c;-s*c, s*c,c^2-s^2];
            stressMode = rotation*stressMode;
            stressModes(counter,:,:) = stressMode;
            
            counter = counter + 1;
        end
        
    end
    
    %interpolate
    crackStressMode = interp1(thetas, stressModes, b.cAngle,'spline');
    phi = [crackStressMode(:,:,1)',crackStressMode(:,:,2)'];
    
end