function [strain, stress] = calcStrainBlocks(cBlocks, groups, FEM, eInd)
    %obtain eigenvalues for block
    groupId = cBlocks.groupID;
    blockType = cBlocks.blockType;
    S_neg  = groups(groupId).type(blockType).lambda;
    Q_u_SD = groups(groupId).type(blockType).Q;
    C_SD   = cBlocks.C;
    
    nodes = cBlocks.nodes;
    SC = cBlocks.SC;
    
    numberOfElements = size(nodes,1)-1;
    elements = zeros(numberOfElements, FEM.nodesPerElement);
    for j = 1:1:numberOfElements
        start = (j-1)*(FEM.nodesPerElement - 1) + 1;
        elements(j,:) = start: start + FEM.nodesPerElement - 1;
    end
    elements(end,end) = 1;
    
    
    
    %obtain nodal coordinates for current element
    [ xCoord , yCoord ] = elementNodeCoordinates( nodes , elements , eInd , FEM.nodesPerElement, SC);

    %recall material properties for each element to form corresponding matrix
    youngsModulus = groups(groupId).E;
    poissonRatio  = groups(groupId).v;
    [ D ] = constitutiveMatrix2D( youngsModulus , poissonRatio , FEM.constitutiveLaw );

    %evaluate shape functions at eta = -1
    samplingPoint = -1;
    [shapeFunction , shapeFunctionDerivative] = shapeFunction1D (FEM.nodesPerElement , samplingPoint, FEM.quadratureType);

    numberOfShapeFunctions = length(shapeFunction);

    %recall interpolation of cartesian coordinates (x,y) and their derivates
    x   = shapeFunction * xCoord;
    y   = shapeFunction * yCoord;
    x_n = shapeFunctionDerivative * xCoord;
    y_n = shapeFunctionDerivative * yCoord;

    %calculate specific jacobian and it's determinant
    detJ = x * y_n - y * x_n;

    %specify shape function for each DOF
        %initialize shape function and it's derivatives in 2D
            shapeFunction2D           = zeros( FEM.DOFPerNode , FEM.DOFPerNode * FEM.nodesPerElement );
            shapeFunctionDerivative2D = zeros( FEM.DOFPerNode , FEM.DOFPerNode * FEM.nodesPerElement );

        %construct shape functions and associated derivaties in 2D
            positionCounter = 1;
            for k = 1:1:numberOfShapeFunctions
                %abbreviation for simple notation
                positionRow = 1:FEM.DOFPerNode;
                positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                shapeFunction2D(positionRow,positionCol)           = shapeFunction(k)           * eye(2);
                shapeFunctionDerivative2D(positionRow,positionCol) = shapeFunctionDerivative(k) * eye(2);
                positionCounter = positionCounter + FEM.DOFPerNode;
            end

    %calculate strain desplacement matrices B1 B2
    B1 =   1/detJ * [y_n ,   0 ;...
                       0 , -x_n;...
                    -x_n ,  y_n] * shapeFunction2D;
    B2 =   1/detJ * [ -y ,   0 ;...
                       0 ,   x ;...
                       x ,  -y ] * shapeFunctionDerivative2D;

    %find element DOF submatrix of Q_u_SD
    elementNodes = elements(eInd,:)';
    eDOF = nodesToDOF(elementNodes, FEM.DOFPerNode);
    Q_u_EL = Q_u_SD(eDOF,:);    

    %calculate stress mode for element
    psi = ( -B1 * Q_u_EL * S_neg + B2 * Q_u_EL);

    strain = psi * C_SD;
    stress = D * strain ;
end