function [strain, stress] = calcStrainPolygons(cBlocks,FEM, eInd)
    %obtain eigenvalues etc. for block
    S_neg  = cBlocks.lambda;
    Q_u_SD = cBlocks.Q;
    C_SD   = cBlocks.C;
    
    nodes = [cBlocks.nodes;cBlocks.nodes(1,:)];
    elements = cBlocks.localElements;
    
    SC = cBlocks.SC;
    
    %obtain nodal coordinates for current element
    [ xCoord , yCoord ] = elementNodeCoordinates( nodes , elements , eInd , FEM.nodesPerElement, SC);

    %recall material properties for each element to form corresponding matrix
    youngsModulus = cBlocks.E;
    poissonRatio  = cBlocks.v;
    [ D ] = constitutiveMatrix2D( youngsModulus , poissonRatio , FEM.constitutiveLaw );

    %evaluate shape functions at eta = -1
    samplingPoint = -1;
    [shapeFunction , shapeFunctionDerivative] = shapeFunction1D (FEM.nodesPerElement , samplingPoint, FEM.quadratureType);

    numberOfShapeFunctions = length(shapeFunction);

    %recall interpolation of cartesian coordinates (x,y) and their derivates
    x   = shapeFunction * xCoord;
    y   = shapeFunction * yCoord;
    x_n = shapeFunctionDerivative * xCoord;
    y_n = shapeFunctionDerivative * yCoord;

    %calculate specific jacobian and it's determinant
    detJ = x * y_n - y * x_n;

    %specify shape function for each DOF
        %initialize shape function and it's derivatives in 2D
            shapeFunction2D           = zeros( FEM.DOFPerNode , FEM.DOFPerNode * FEM.nodesPerElement );
            shapeFunctionDerivative2D = zeros( FEM.DOFPerNode , FEM.DOFPerNode * FEM.nodesPerElement );

        %construct shape functions and associated derivaties in 2D
            positionCounter = 1;
            for k = 1:1:numberOfShapeFunctions
                %abbreviation for simple notation
                positionRow = 1:FEM.DOFPerNode;
                positionCol = positionCounter : positionCounter + FEM.DOFPerNode - 1;

                shapeFunction2D(positionRow,positionCol)           = shapeFunction(k)           * eye(2);
                shapeFunctionDerivative2D(positionRow,positionCol) = shapeFunctionDerivative(k) * eye(2);
                positionCounter = positionCounter + FEM.DOFPerNode;
            end

    %calculate strain desplacement matrices B1 B2
    B1 =   1/detJ * [y_n ,   0 ;...
                       0 , -x_n;...
                    -x_n ,  y_n] * shapeFunction2D;
    B2 =   1/detJ * [ -y ,   0 ;...
                       0 ,   x ;...
                       x ,  -y ] * shapeFunctionDerivative2D;

    %find element DOF submatrix of Q_u_SD
    elementNodes = elements(eInd,:)';
    eDOF = nodesToDOF(elementNodes, FEM.DOFPerNode);
    Q_u_EL = Q_u_SD(eDOF,:);    

    %calculate stress mode for element
    psi = ( -B1 * Q_u_EL * S_neg + B2 * Q_u_EL);
    %correct stresses on boundary at gauss sampling points
    strain = psi *C_SD;
    stress = D * strain ;
end