%create explicit points and generate signed distance funciton fields

%%  general
    qt.nDomains  = length(domain);
    qt.nFeatures = length(feature);
    qt.nCracks   = length(crack);

%%  determine bounding box
    qt.bBox = [inf,inf;-inf,-inf];
    for i = 1:1:qt.nDomains
        switch domain(i).type{1}
            case 'polyline'
                minX = min(domain(i).edges(:,1));
                maxX = max(domain(i).edges(:,1));      
                minY = min(domain(i).edges(:,2));
                maxY = max(domain(i).edges(:,2));
            case 'ellipse'
                minX = domain(i).edges(1,1)-domain(i).edges(2,1);
                maxX = domain(i).edges(1,1)+domain(i).edges(2,1);     
                minY = domain(i).edges(1,2)-domain(i).edges(2,2);
                maxY = domain(i).edges(1,2)+domain(i).edges(2,2);
            otherwise; disp('case not implemented yet')
        end
        qt.bBox(1,:) = min(qt.bBox(1,:),[minX,minY]);
        qt.bBox(2,:) = max(qt.bBox(2,:),[maxX,maxY]);
    end

%%  scale domains and features to specified discretization qt.size
    diffX = diff(qt.bBox(:,1)); diffY = diff(qt.bBox(:,2));
    scaleX = diffX/qt.size; scaleY = diffY/qt.size; scale = max(scaleX,scaleY);
    if scale >= 0.8 && scale <= 1 
        qt.scale = 1;
        %only shift points by (bP(xMin), bP(yMin))
        for i = 1:1:qt.nDomains
            switch domain(i).type{1}
                case 'polyline'
                    domain(i).edges(:,1) = domain(i).edges(:,1) - qt.bBox(1,1);
                    domain(i).edges(:,2) = domain(i).edges(:,2) - qt.bBox(1,2);
                case 'ellipse'
                    domain(i).edges(1,1) = domain(i).edges(1,1) - qt.bBox(1,1);
                    domain(i).edges(1,2) = domain(i).edges(1,2) - qt.bBox(1,2);
                otherwise; disp('case not implemented yet')
            end
        end
        for i = 1:1:qt.nFeatures
            switch domain(i).type{1}
                case 'polyline'
                    feature(i).edges(:,1) = feature(i).edges(:,1) - qt.bBox(1,1);
                    feature(i).edges(:,2) = feature(i).edges(:,2) - qt.bBox(1,2);
                case 'ellipse'
                    feature(i).edges(1,1) = feature(i).edges(1,1) - qt.bBox(1,1);
                    feature(i).edges(1,2) = feature(i).edges(1,2) - qt.bBox(1,2);
                otherwise; disp('case not implemented yet')
            end
        end
    else
        qt.scale = scale;
        %shift points to xMin, yMin and then scale by factor
        for i = 1:1:qt.nDomains
            switch domain(i).type{1}
                case 'polyline'
                    domain(i).edges(:,1) = (domain(i).edges(:,1) - qt.bBox(1,1))/qt.scale;
                    domain(i).edges(:,2) = (domain(i).edges(:,2) - qt.bBox(1,2))/qt.scale;
                case 'ellipse'
                    domain(i).edges(1,1) = (domain(i).edges(1,1) - qt.bBox(1,1))/qt.scale;
                    domain(i).edges(1,2) = (domain(i).edges(1,2) - qt.bBox(1,2))/qt.scale;
                    domain(i).edges(2,1) =  domain(i).edges(2,1)                /qt.scale;
                    domain(i).edges(2,2) =  domain(i).edges(2,2)                /qt.scale;
                otherwise; disp('case not implemented yet')
            end
        end
        for i = 1:1:qt.nFeatures
            switch feature(i).type{1}
                case 'polyline'
                    feature(i).edges(:,1) = (feature(i).edges(:,1) - qt.bBox(1,1))/qt.scale;
                    feature(i).edges(:,2) = (feature(i).edges(:,2) - qt.bBox(1,2))/qt.scale;
                case 'ellipse'
                    feature(i).edges(1,1) = (feature(i).edges(1,1) - qt.bBox(1,1))/qt.scale;
                    feature(i).edges(1,2) = (feature(i).edges(1,2) - qt.bBox(1,2))/qt.scale;
                    feature(i).edges(2,1) =  feature(i).edges(2,1)                /qt.scale;
                    feature(i).edges(2,2) =  feature(i).edges(2,2)                /qt.scale;
                otherwise; disp('case not implemented yet')
            end
        end
        for i = 1:1:qt.nCracks
            crack(i).points(:,1) = (crack(i).points(:,1) - qt.bBox(1,1))/qt.scale;
            crack(i).points(:,2) = (crack(i).points(:,2) - qt.bBox(1,2))/qt.scale;
        end

    end

%%  Initialize qtArray --> eventually use some more sophisticated heuristics
    qt.maxLeaf = 0;
    for i = 0:1:log2(qt.size)-log2(qt.decompMin)
        y = 2^i;
        qt.maxLeaf = qt.maxLeaf + y*y;
    end
    qtArray = zeros(qt.maxLeaf,11);
    
%%  Calculate explicit points by performing polygon clipping
    clipGroups
    
%%  Implicit signed distance functions
    %generate points via meshgrid
    x = 0:1:qt.size; 
    y = x;
    [gridX,gridY] = meshgrid(x,y);
    points = [gridX(:),gridY(:)];    
    %% domain
    %itinialize field
    qt.domainImp = [];

    for i = 1:1:qt.nDomains
        switch domain(i).type{1}
            case 'polyline'
                %sort edges in ccw direction (left of line is inside domain)
                [domain(i).edges(:,1),domain(i).edges(:,2)] = poly2ccw(domain(i).edges(:,1),domain(i).edges(:,2));
                %initialize data sets for later boolean operations
                sdEval = zeros(length(points),size(domain(i).edges,1));
                for  j = 1:1:size(domain(i).edges,1)
                    if j ~= size(domain(i).edges,1)
                        sP = domain(i).edges(j  ,:);
                        eP = domain(i).edges(j+1,:);
                    else
                        sP = domain(i).edges(j,:);
                        eP = domain(i).edges(1,:);
                    end
                    sdEval(:,j) = sdLine(points, sP,eP);
                end
                sdEval = sdIntersect(sdEval);

            case 'ellipse'
                sdEval = sdCircle(points,domain(i).edges);

            otherwise; disp('case not implemented yet')
        end

        %merge with existing field
        switch domain(i).type{2}
            case 'plus'
                qt.domainImp =  sdUnion([qt.domainImp,sdEval]);
            case 'minus'
                qt.domainImp =  sdDiff([qt.domainImp,sdEval]);
            otherwise; disp('implicit boolean operation not implemented yet')
        end

    end
    %qt.domainImp(qt.domainImp > 0) = nan;
    %contourf(gridX,gridY,reshape(qt.domainImp,1025,1025));axis equal
    
    %% features
    qt.featureImp{1} = qt.domainImp;
    featureID = [];
    for i = 1:1:qt.nFeatures
        featureID = [featureID, feature(i).type{3}];
    end
    [featureID, ~, oldInd] = uniquetol(featureID);
    if featureID == 1
        qt.nGroups = 1;
    else
        for i = 1:1:length(featureID)
            qt.featureImp{featureID(i)} = [];
        end
        for i = 1:1:length(featureID)
            %find indices of features pertaining to current group
            [~,ind] = find(featureID(i)==featureID(oldInd));
            sdEval = [];
            %make new group based on summation
            for j = 1:1:length(ind)
                switch feature(ind(j)).type{1}
                    case 'polyline'
                        %sort edges in ccw direction (left of line is inside domain)
                        [feature(ind(j)).edges(:,1),feature(ind(j)).edges(:,2)] = poly2ccw(feature(ind(j)).edges(:,1),feature(ind(j)).edges(:,2));
                        %initialize data sets for later boolean operations
                        sdEval = zeros(length(points),size(feature(ind(j)).edges,1));
                        for  k = 1:1:size(feature(ind(j)).edges,1)
                            if k ~= size(feature(ind(j)).edges,1)
                                sP = feature(ind(j)).edges(k  ,:);
                                eP = feature(ind(j)).edges(k+1,:);
                            else
                                sP = feature(ind(j)).edges(k,:);
                                eP = feature(ind(j)).edges(1,:);
                            end
                            sdEval(:,k) = sdLine(points, sP,eP);
                        end
                        sdEval = sdIntersect(sdEval);
                    case 'ellipse'
                        sdEval = sdCircle(points,feature(ind(j)).edges);
                    otherwise; disp('case not implemented yet')
                end
                switch feature(ind(j)).type{2}
                    case 'plus'
                        qt.featureImp{featureID(i)} =  sdUnion([qt.featureImp{featureID(i)},sdEval]);
                    case 'minus'; disp('casenot implemented yet')
                    otherwise; disp('implicit boolean operation not implemented yet')
                end
            end
            qt.featureImp{1} = sdDiff([qt.featureImp{1},qt.featureImp{featureID(i)}]);
        end
    end
        %plot
        %{
        hold on
        qt.featureImp{1}(qt.featureImp{1} > 0) = nan;
        contourf(gridX,gridY,reshape(qt.featureImp{1},1025,1025));axis equal
        qt.featureImp{2}(qt.featureImp{2} > 0) = nan;
        contourf(gridX,gridY,reshape(qt.featureImp{2},1025,1025));axis equal
        qt.featureImp{3}(qt.featureImp{3} > 0) = nan;
        contourf(gridX,gridY,reshape(qt.featureImp{3},1025,1025));axis equal
        hold off
        %}
    
    %% crack
    for i = 1:1:qt.nCracks
        %reinitialize clean temporary 
        crackLine  = [];
        crackRange = [];
        
        %sd-function collinear to crack direction
        sP = crack(i).points(1,:); eP = crack(i).points(2,:);
        sdEval = sdLine(points, sP,eP);
        crackLine =  sdUnion([crackLine,sdEval]);
        
        %front tip sd-function perpendicular to crack direction
        dx = eP(1)-sP(1); dy = eP(2)-sP(2); sP = eP; eP = sP + [-dy,dx];
        sdEval = sdLine(points, sP,eP);
        crackRange =  sdUnion([crackRange,sdEval]);
        %back tip sd-function perpendicular to crack direction
        sP = crack(i).points(1,:); eP = sP + [dy,-dx];
        sdEval = sdLine(points, sP,eP);
        crackRange =  sdIntersect([crackRange,sdEval]);
        
        %save to proper matrix position
        qt.crack{i}.line  = crackLine;
        qt.crack{i}.range = crackRange;
    end
    
        %hold on
        %crackLine(crackLine > 0) = nan;
        %contourf(gridX,gridY,reshape(crackLine,1025,1025));axis equal
        %crackRange(crackRange > 0) = nan;
        %contourf(gridX,gridY,reshape(crackRange,1025,1025));axis equal
        %scatter(crack(1).points(:,1),crack(1).points(:,2))
        %plot(crack(1).points(:,1),crack(1).points(:,2))
        %hold off
        
%%  Reshape all implicit fields
    qt.reshapeSize = length(x);
    %domain
    qt.domainImp = reshape(qt.domainImp,qt.reshapeSize,qt.reshapeSize);
    %features
    for i = 1:1:qt.nGroups
        qt.featureImp{i} = reshape(qt.featureImp{i},qt.reshapeSize,qt.reshapeSize);
    end
    %cracks
    for i = 1:1:qt.nCracks
        qt.crack{i}.line  = reshape(qt.crack{i}.line ,qt.reshapeSize,qt.reshapeSize);
        qt.crack{i}.range = reshape(qt.crack{i}.range,qt.reshapeSize,qt.reshapeSize);
    end
    
%%  Clean up
    clear -regexp ^diff ^max ^min ^x ^y ^sd
    clear dx dy sP eP featureID i j ind oldInd scaleX scaleY reshapeSize
    

        
    %plot resulting shape
    %{
    [f1, v1] = poly2fv(qt.domainExp(:,1),qt.domainExp(:,2));
    [f2, v2] = poly2fv(qt.featureExp{1,1}(:,1),qt.featureExp{1,1}(:,2));
    [f3, v3] = poly2fv(qt.featureExp{1,2}(:,1),qt.featureExp{1,2}(:,2));
    hold on
    patch('Faces', f1, 'Vertices', v1, 'FaceColor', 'r', ...
    'EdgeColor', 'none','FaceAlpha',0.3)
    patch('Faces', f2, 'Vertices', v2, 'FaceColor', 'r', ...
    'EdgeColor', 'none','FaceAlpha',0.7)
    patch('Faces', f3, 'Vertices', v3, 'FaceColor', 'r', ...
    'EdgeColor', 'none','FaceAlpha',0.7)
    axis equal
    scatter(qt.domainExp(:,1),qt.domainExp(:,2),'+')
    scatter(qt.featureExp{1,1}(:,1),qt.featureExp{1,1}(:,2),'+')
    scatter(qt.featureExp{1,2}(:,1),qt.featureExp{1,2}(:,2),'+')
    hold off
    %}

return








