%%  Quadtree decomposition for subsequent SBFEM analysis


%%  Clean up
        %clear all;
        %close all;
        %clear qtArray;

%%  Parameters
    %General
        %rng default
    
    %quadtree decomposition
        %define minimum and maximum block sizes
        qt.decompMin =   1;
        qt.decompMax = 128;
        %define difference in grayscale value of a block to split
        qt.decompThreshold = 0.3;
        %unbalanced (0) or balanced (1) quadtree decomposition
        qt.decompBalance = 0; 
        %general tree information
        qt.nKids = 4;
        %maximum number of points within block
        qt.maxSeeds = 1;

%%  Initialize

%%  Generate input
    %from image
        %initialiaze if necessary
            qt.imageSize = 512;
            qt.image = zeros(qt.imageSize);
        %from file
            %%{
            %read image
            qt.image = imread('einstein.bmp');
            %correct orientation
            qt.image = flipud(qt.image);
            %scale if necessary in size
            scale = 0.9;
            qt.image = imresize(qt.image,scale);
            %}
        %user specified
            %%{
            %change portions of image
                qt.image(32:64,:) = 255;
            %}
        %scale in values from 255 to values between 0&1
            qt.image = double(qt.image);
            qt.image = qt.image./255;
        %contourf(qt.image,'LineColor','none');axis equal;
        
    %from features
        qt.bPgon = polyshape();
        %explicit border
            %trapez
                qt.bPArray(1).edges  = [50,150;50,50;400,0;400,200];
                qt.bPArray(1).seeds  = [2,20,2,20];
                qt.bPArray(1).pgon   = polyshape(qt.bPArray(1).edges);
                
            %circle 1
                qt.bPArray(2).edges  = [50,50;50,100];
                qt.bPArray(2).seeds  = 25;
                qt.bPArray(2).points = subdivideSide_elipse(qt.bPArray(2).edges,qt.bPArray(2).seeds);
                qt.bPArray(2).pgon   = polyshape(qt.bPArray(2).points);
                
            %circle 2
                qt.bPArray(3).edges  = [100,100;400,100];
                qt.bPArray(3).seeds  = 25;
                qt.bPArray(3).points = subdivideSide_elipse(qt.bPArray(3).edges,qt.bPArray(3).seeds);
                qt.bPArray(3).pgon   = polyshape(qt.bPArray(3).points);
            
            %cutout circle 3
                qt.bPArray(4).edges  = [20,20;50,100];
                qt.bPArray(4).seeds  = 25;
                qt.bPArray(4).points = subdivideSide_elipse(qt.bPArray(4).edges,qt.bPArray(4).seeds);
                qt.bPArray(4).pgon   = polyshape(qt.bPArray(4).points);
            
            %cutout circle 4
                qt.bPArray(5).edges  = [40,40;400,100];
                qt.bPArray(5).seeds  = 25;
                qt.bPArray(5).points = subdivideSide_elipse(qt.bPArray(5).edges,qt.bPArray(5).seeds);
                qt.bPArray(5).pgon   = polyshape(qt.bPArray(5).points);
            
            %add
                qt.bPgon = union([qt.bPArray(1:3).pgon]);
            %subtract
                qt.bPgon = subtract(qt.bPgon,qt.bPArray(4).pgon);
                qt.bPgon = subtract(qt.bPgon,qt.bPArray(5).pgon);

            %subdivide lines
                addPoints = subdivideSide_linear( qt.bPArray(1).edges, qt.bPArray(1).seeds);
                qt.bPPoints = [addPoints;qt.bPgon.Vertices];

            %reorder
                qt.bPPoints = sortCCW(qt.bPPoints);
                
        %Pad image
            [qt] = padInput( qt );
            %uniform for testing purposes
            qt.imagePad(1:end,1:end) = 1; 
            
        %implicit definitions
            %generate points via meshgrid
            x = 0:qt.imageSize; 
            y = x;
            [X,Y] = meshgrid(x,y);
            points = [X(:),Y(:)];
            
            %initialize data sets for later boolean operations
            sdEval = zeros(length(points),length(qt.bPArray(1).edges));
            %trapez (as intersect of individual lines)
            for i = 1:1:length(qt.bPArray(1).edges)
                if i ~= length(qt.bPArray(1).edges)
                    sP = qt.bPArray(1).edges(i  ,:);
                    eP = qt.bPArray(1).edges(i+1,:);
                else
                    sP = qt.bPArray(1).edges(i,:);
                    eP = qt.bPArray(1).edges(1,:);
                end
                sdEval(:,i) = sdLine(points, sP,eP);
            end
            sdBool = sdIntersect(sdEval);
            
            %circle 1
            sdEval = sdCircle(points,qt.bPArray(2).edges);
            sdBool = sdUnion([sdEval,sdBool]);
            
            %circle 2
            sdEval = sdCircle(points,qt.bPArray(3).edges);
            sdBool = sdUnion([sdEval,sdBool]);
            
            %cutout 1
            sdEval = sdCircle(points,qt.bPArray(4).edges);
            sdBool = sdDiff([sdBool,sdEval]);
            
            %cutout 2
            sdEval = sdCircle(points,qt.bPArray(5).edges);
            sdBool = sdDiff([sdBool,sdEval]);
            
            %boundary signed distance function evaluated at each point on domain
            qt.bSD = sdBool;
            
            %plotting
                %sdBool(sdBool > 0) = nan;
                %contourf(X,Y,reshape(sdBool,513,513));axis equal
    
    %specified features
        qt.fPgon = polyshape();
        %explicit border
            %circle 1 with material 1
                qt.bPArray(6).edges  = [40,40;150,100];
                qt.bPArray(6).seeds  = 25;
                qt.bPArray(6).points = subdivideSide_elipse(qt.bPArray(6).edges,qt.bPArray(6).seeds);
                qt.bPArray(6).pgon   = polyshape(qt.bPArray(6).points);

            %circle 2 with material 2
                qt.bPArray(7).edges  = [50,50;275,100];
                qt.bPArray(7).seeds  = 25;
                qt.bPArray(7).points = subdivideSide_elipse(qt.bPArray(7).edges,qt.bPArray(7).seeds);
                qt.bPArray(7).pgon   = polyshape(qt.bPArray(7).points);
                
            %create feature related points
                qt.fPPoints = [qt.bPArray(6).points;[nan,nan];qt.bPArray(7).points];
            %reorder
                qt.fPPoints = sortCCW(qt.fPPoints);
        
        %implicit border
            %circle 1
            sdEval = sdCircle(points,qt.bPArray(6).edges);
            qt.fSD(1).sd = sdEval;
            
            %circle 2
            sdEval = sdCircle(points,qt.bPArray(7).edges);
            qt.fSD(2).sd = sdEval;
            
            %plotting
                %qt.fSD(1).sd(qt.fSD(1).sd > 0) = nan;
                %contourf(X,Y,reshape(qt.fSD(1).sd,513,513));axis equal
                %qt.fSD(2).sd(qt.fSD(2).sd > 0) = nan;
                %contourf(X,Y,reshape(qt.fSD(2).sd,513,513));axis equal

    %visualize defined input
        %{
        hold on
        plot(qt.bPgon)
        plot(qt.bPArray(6).pgon)
        plot(qt.bPArray(7).pgon)
        axis equal
        hold off
        %}
    
%%  Option to scale inputs to better fit quadtree inherent discretization
    %has to be done directly after the construction of the explicit points
    %these have to be scaled by (1-tol) and then moved by (tol/2,tol/2)

%%  Allocate memory to tree (-like array of structs)
    %change this to reflect the minimum decomposition size
    qt.maxLeaf = 0;
    for i = 0:1:log2(qt.imageSize)-log2(qt.decompMin)
        y = 2^i;
        qt.maxLeaf = qt.maxLeaf + y*y;
    end

    qtArray(qt.maxLeaf).parent     = -1;
    qtArray(qt.maxLeaf).kids       = [-1,-1,-1,-1];
    qtArray(qt.maxLeaf).position   = [-1,-1];
    qtArray(qt.maxLeaf).size       = -1;
    qtArray(qt.maxLeaf).active     = -1;
    qtArray(qt.maxLeaf).level      = -1;
    qtArray(qt.maxLeaf).nSeeds     = -1;
    qtArray(qt.maxLeaf).seeds      = -1;
    qtArray(qt.maxLeaf).diffInt    = -1;
    qtArray(qt.maxLeaf).neighbours = -1;
    
%%  Assign data to root node
    root = 1;
    qtArray(root).parent   = 0;
    qtArray(root).position = [1,1];
    qtArray(root).size     = qt.imageSize;
    qtArray(root).active   = 1;
    qtArray(root).level    = 0;
    %assign all explicit points to root
    seeds = [qt.bPPoints;qt.fPPoints];
    seeds(~any(~isnan(seeds), 2),:) = [];
    seeds = sortrows(seeds,[1,2]);
    qtArray(root).seeds   = seeds;
    qtArray(root).nSeeds  = length(qtArray(root).seeds);
    
%%  Perform splitting due to qt.decompMax
tic
    [qt, qtArray] = qtDecompUnbalanced(qt,qtArray);
toc
%%  Determine neightbours for each active block
    %{
    %reset id
    id = 1;
    %continue while there are still valid blocks in qtArray
    while (~isempty(qtArray(id).level))
        %if (id == 144)
        if (qtArray(id).active == 1) %only compute neighbours for active blocks
            %should be stored as cellarray
            qtArray(id).neighbours = getNeighbours(qtArray,id);
        end
        id = id + 1;
    end
    %}
return
%%  Balance decomposition
    bVec = zeros(1,qt.nDecomp);
    for  i = 1:1:qt.nDecomp
        bVec(i) = qtArray(i).active;
    end
    bList = find(bVec);

    id = 1;
    while (id <= length(bList)) && (qt.decompBalance == 1)
        if qtArray(bList(id)).active == 1
            %update neighbours of block
            qtArray(bList(id)).neighbours = getNeighbours(qtArray,bList(id));
            %check if split is necessary based on current neighbours
            [ bool ] = splitBlock(qtArray,bList(id));
            if bool % split
                %update parent's information
                qtArray(bList(id)).kids   = qt.nDecomp+1 : qt.nDecomp+qt.nKids;
                qtArray(bList(id)).active = 0;
                %determine which seeds belong to which quadrant
                [sQ1,sQ2,sQ3,sQ4] = seedsQuadrant(qtArray,bList(id));
                %update kid's information
                for i = 1:1:qt.nKids
                    kidId = qtArray(bList(id)).kids(i);
                    qtArray(kidId).parent   = bList(id);
                    qtArray(kidId).size     = qtArray(bList(id)).size / 2;
                    qtArray(kidId).active   = 1;
                    qtArray(kidId).level    = qtArray(bList(id)).level + 1;
                    %distribute seeds as they are positioned via function call
                    switch i
                        case 1; qtArray(kidId).position = qtArray(bList(id)).position + [qtArray(kidId).size,qtArray(kidId).size];
                                qtArray(kidId).seeds = sQ1; qtArray(kidId).nSeeds = length(qtArray(kidId).seeds);
                        case 4; qtArray(kidId).position = qtArray(bList(id)).position + [qtArray(kidId).size,                  0];
                                qtArray(kidId).seeds = sQ2; qtArray(kidId).nSeeds = length(qtArray(kidId).seeds);
                        case 3; qtArray(kidId).position = qtArray(bList(id)).position + [                  0,                  0];
                                qtArray(kidId).seeds = sQ3; qtArray(kidId).nSeeds = length(qtArray(kidId).seeds);
                        case 2; qtArray(kidId).position = qtArray(bList(id)).position + [                  0,qtArray(kidId).size];
                                qtArray(kidId).seeds = sQ4; qtArray(kidId).nSeeds = length(qtArray(kidId).seeds);
                    end
                end
                qt.nDecomp = qt.nDecomp + qt.nKids;

                %calculate children neighbours and add them to bList
                for i = 1:1:qt.nKids
                    kidId = qtArray(bList(id)).kids(i);
                    %determine neighbours
                    qtArray(kidId).neighbours = getNeighbours(qtArray,kidId);
                    %add to list
                    bList = [bList,[qtArray(kidId).neighbours{:}]];
                end
            end
        end
        id = id + 1;
    end

%%  Mark elements within domain and  assign material type (z.B. 1 = domain, 2 = transition, 3 = void)

    
%%  plot decomposition
    %{
    clf
    %f1 = figure;
    hold on
    for i = 1:1:qt.nDecomp
        if (qtArray(i).active == 1)
            %disp('active element')
        sNX = qtArray(i).position(1);
        eNX = qtArray(i).size;
        sNY = qtArray(i).position(2);
        eNY = qtArray(i).size;
            if qt.imagePad(sNY,sNX) < qt.decompThreshold
                vec = [1,0,0]; %red
            else
                vec = [0,1,0]; %green
            end
        poly = [[sNX,sNX+eNX,sNX+eNX,sNX,sNX]',[sNY,sNY,sNY+eNY,sNY+eNY,sNY]']-1;
        midX = mean(poly(:,1));
        midY = mean(poly(:,2));
        fill(poly(:,1),poly(:,2),vec)
        %text(midX,midY,num2str(i))
        end
    end
    axis equal
    xlim([0 inf])
    ylim([0 inf])
    
    %specified input
        plot(qt.bPgon)
        plot(qt.bPArray(6).pgon)
        plot(qt.bPArray(7).pgon)
    
    hold off
    %}    
