%%  Reset
    clear cBlocks
%%  Timing
    tic
%%  Input file
    [qt, poly, domain, feature, crack, groups, FEM, BC, Load] = Input_File_1();
    
%%  Prepocessor (hope this can be done in just around 1 sec)
    %parse input file by constructing explicit and implicit geometry representations
    preProcessor
    
    %unbalanced quadtree decomposition
    qtDecompUnbalanced
    if qt.plotUnbalanced; qtPlot; end
    
    %balance quadtree decomposition
    qtDecompBalance
    if qt.plotBalanced; qtPlot; end

    %classify blocks
    classifyBocks %--> override for testing!!!!!
    if qt.plotDomain; qtPlotPartial; end
    
    %determine general block information
    blockInfo

    %split transition blocks based on their signed distance function
    splitTransitionBlocks
    if qt.plotTransition; qtPlotTransitionBlocks; end

    %add crack
    splitCrackBlocks  %--> override for testing!!!!!
    if qt.plotTransition; qtPlotCrackedBlocks; end
    
    %scale all dimensions back to original size
    scaleGeometryBack

    %find global identifiers for all nodes
    assignGlobalDOF
    if qt.plotFinalMesh; qtPlotPreProcessorMesh; end

    %move nodes to fixed points and update touching blocks to polygon
    moveNodes
    
    disp('preprocessor')
    toc

%%  Processor    
        
    %precalc stiffness matrices
    tic
        precomputeK
        disp('precompute K')
    toc

    %determine stiffness matrix for all polygons
    tic
        polygonK
        disp('polygon K')
    toc
    
    %determine loading
        FEM.F = zeros(FEM.nDOF,1);
        assembleF  %--> override for testing!!!!!

    %assemble K
    tic
        assembleK
        disp('assemble K')
    toc

    %determine boundary conditions
    tic
        enforceBC %--> override for testing!!!!!
        disp('enforce BC')
    toc
    
    %solve finite element equilibrium equation U = K\F
    tic
        FEM.U = FEM.K\FEM.F;
        disp('Solve U = K\F')
    toc
    
%%  Postprocessor
    %determine displacements for each polygon
        postDisplacements
        
        %cBlocks(1).polygon(1).U = FEM.U;%--> override for testing!!!!!
        
    %determine displacements for each node and plot
        %qtPlotDisplacements
    
    %determine coefficient vector
        postIntC
    
    %determine strains and stress at nodes
    tic
        postStrain
        disp('post process strains and stress')
    toc
    
    %plot strain and stress results
        qt.plotField     = 'stress';
        qt.plotFieldType = 'von Mises'; 
        qt.plotDisplaced = 1;
        %qtPlotStrainStress
        
    %output strains at certain points
    %sensorStrains
    
    %determine SIFs
    tic
        postSIFs
        disp('post process SIFs')
    toc
    
return






